#!/bin/bash

# A nightly test, which is just a collection of other tests.
# If you are adding a test, make sure the binaries/scripts it needs are
# also part of what buildomat puts in the nightly archive, currently
# generated in: .github/buildomat/jobs/build-release.sh

SECONDS=0
err=0
output_file="/tmp/nightly_results"
rm -f "$output_file"

ROOT=$(cd "$(dirname "$0")/.." && pwd)
cd "$ROOT" || (echo failed to cd "$ROOT"; exit 1)
export BINDIR=${BINDIR:-$ROOT/target/release}

echo "Nightly starts at $(date)" | tee "$output_file"
echo "$(date) hammer start" >> "$output_file"
banner hammer
./tools/hammer_loop.sh -l 200
res=$?
if [[ "$res" -eq 0 ]]; then
    echo "$(date) hammer pass" >> "$output_file"
else
    echo "$(date) hammer fail with: $res" >> "$output_file"
    (( err += 1 ))
fi

banner replay
echo "$(date) replay start" >> "$output_file"
./tools/test_replay.sh -l 200
res=$?
if [[ "$res" -eq 0 ]]; then
    echo "$(date) replay pass" >> "$output_file"
else
    echo "$(date) replay fail with: $res" >> "$output_file"
    (( err += 1 ))
fi

banner repair
echo "$(date) repair start" >> "$output_file"
./tools/test_repair.sh -l 500
res=$?
if [[ "$res" -eq 0 ]]; then
    echo "$(date) repair pass" >> "$output_file"
else
    echo "$(date) repair fail with: $res" >> "$output_file"
    (( err += 1 ))
fi

banner restart_repair
echo "$(date) restart_repair start" >> "$output_file"
./tools/test_restart_repair.sh -l 200
res=$?
if [[ "$res" -eq 0 ]]; then
    echo "$(date) restart_repair pass" >> "$output_file"
else
    echo "$(date) restart_repair fail with: $res" >> "$output_file"
    (( err += 1 ))
fi

banner live_repair
echo "$(date) live_repair start" >> "$output_file"
./tools/test_live_repair.sh -l 20
res=$?
if [[ "$res" -eq 0 ]]; then
    echo "$(date) live_repair pass" >> "$output_file"
else
    echo "$(date) live_repair fail with: $res" >> "$output_file"
    (( err += 1 ))
fi

banner replace_reconcile
echo "$(date) replace_reconcile start" >> "$output_file"
./tools/test_replace_special.sh -l 20
res=$?
if [[ "$res" -eq 0 ]]; then
    echo "$(date) replace_reconcile pass" >> "$output_file"
else
    echo "$(date) replace_reconcile fail with: $res" >> "$output_file"
    (( err += 1 ))
fi
duration=$SECONDS

banner results
cat "$output_file"
printf "Tests took %d:%02d  errors:%d\n" \
    $((duration / 60)) $((duration % 60)) "$err"

